#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const tslint_1 = require("tslint");
const typescript_1 = __importDefault(require("typescript"));
const test_1 = require("./test");
class FormatTypescriptHost {
    getCurrentDirectory() {
        return process.cwd();
    }
    getCanonicalFileName(fileName) {
        return fileName;
    }
    getNewLine() {
        return '\n';
    }
}
function lint(fix) {
    const program = tslint_1.Linter.createProgram(path_1.default.resolve(process.cwd(), 'tsconfig.json'), process.cwd());
    const linter = new tslint_1.Linter({
        fix: !!fix,
    }, program);
    const diagnostics = [
        ...program.getSemanticDiagnostics(),
        ...program.getSyntacticDiagnostics(),
    ];
    if (diagnostics.length > 0) {
        console.log(typescript_1.default.formatDiagnosticsWithColorAndContext(diagnostics, new FormatTypescriptHost()));
        process.exit(1);
    }
    for (const file of tslint_1.Linter.getFileNames(program)) {
        const sourceFile = program.getSourceFile(file);
        const content = sourceFile.text;
        const configuration = tslint_1.Configuration.findConfiguration(null, file).results;
        linter.lint(file, content, configuration);
    }
    const results = linter.getResult();
    console.log(results.output);
    return results.errorCount === 0;
}
exports.lint = lint;
function check() {
    return __awaiter(this, void 0, void 0, function* () {
        lint();
        return test_1.test();
    });
}
exports.check = check;
if (require.main === module) {
    check().catch(() => process.exit(1));
}
//# sourceMappingURL=check.js.map